@@ -43,9 +43,7 @@ DEFAULT_BASE_URL = os.environ.get('COUCHDB_URL', 'http://localhost:5984/')
 class Server(object):
     """Representation of a CouchDB server.
 
-    >>> server = Server() # connects to the local_server
-    >>> remote_server = Server('http://example.com:5984/')
-    >>> secure_remote_server = Server('https://username:password@example.com:5984/')
+    >>> server = Server()
 
     This class behaves like a dictionary of databases. For example, to get a
     list of database names on the server, you can simply iterate over the
@@ -273,12 +271,6 @@ class Database(object):
     2
 
     >>> del server['python-tests']
-
-    If you need to connect to a database with an unverified or self-signed SSL
-    certificate, you can re-initialize your ConnectionPool as follows (only
-    applicable for Python 2.7.9+):
-
-    >>> db.resource.session.disable_ssl_verification()
     """
 
     def __init__(self, url, name=None, session=None):
@@ -1011,8 +1003,7 @@ class Document(dict):
 
         :rtype: basestring
         """
-        return self.get('_id')
-
+        return self['_id']
 
     @property
     def rev(self):
@@ -1020,7 +1011,7 @@ class Document(dict):
 
         :rtype: basestring
         """
-        return self.get('_rev')
+        return self['_rev']
 
 
 class View(object):
