@@ -17,7 +17,6 @@ import errno
 import socket
 import time
 import sys
-import ssl
 
 try:
     from threading import Lock
@@ -54,7 +53,7 @@ if sys.version < '2.7':
 
         Based on code originally copied from Python 2.7's httplib module.
         """
-
+        
         def endheaders(self, message_body=None):
             if self.__dict__['_HTTPConnection__state'] == _CS_REQ_STARTED:
                 self.__dict__['_HTTPConnection__state'] = _CS_REQ_SENT
@@ -160,9 +159,7 @@ class ResponseBody(object):
 
     def close(self):
         while not self.resp.isclosed():
-            chunk = self.resp.read(CHUNK_SIZE)
-            if not chunk:
-                self.resp.close()
+            self.resp.read(CHUNK_SIZE)
         if self.conn:
             self._release_conn()
 
@@ -219,24 +216,10 @@ class Session(object):
         self.cache = cache
         self.max_redirects = max_redirects
         self.perm_redirects = {}
-
-        self._disable_ssl_verification = False
-        self._timeout = timeout
-        self.connection_pool = ConnectionPool(
-            self._timeout,
-            disable_ssl_verification=self._disable_ssl_verification)
-
+        self.connection_pool = ConnectionPool(timeout)
         self.retry_delays = list(retry_delays) # We don't want this changing on us.
         self.retryable_errors = set(retryable_errors)
 
-    def disable_ssl_verification(self):
-        """Disable verification of SSL certificates and re-initialize the
-        ConnectionPool. Only applicable on Python 2.7.9+ as previous versions
-        of Python don't verify SSL certs."""
-        self._disable_ssl_verification = True
-        self.connection_pool = ConnectionPool(self._timeout,
-            disable_ssl_verification=self._disable_ssl_verification)
-
     def request(self, method, url, body=None, headers=None, credentials=None,
                 num_redirects=0):
         if url in self.perm_redirects:
@@ -437,22 +420,11 @@ class Cache(object):
         self.by_url = dict(ls[-self.keep_size:])
 
 
-class InsecureHTTPSConnection(HTTPSConnection):
-    """Wrapper class to create an HTTPSConnection without SSL verification
-    (the default behavior in Python < 2.7.9). See:
-    https://docs.python.org/2/library/httplib.html#httplib.HTTPSConnection"""
-    if sys.version_info >= (2, 7, 9):
-        def __init__(self, *a, **k):
-            k['context'] = ssl._create_unverified_context()
-            HTTPSConnection.__init__(self, *a, **k)
-
-
 class ConnectionPool(object):
     """HTTP connection pool."""
 
-    def __init__(self, timeout, disable_ssl_verification=False):
+    def __init__(self, timeout):
         self.timeout = timeout
-        self.disable_ssl_verification = disable_ssl_verification
         self.conns = {} # HTTP connections keyed by (scheme, host)
         self.lock = Lock()
 
@@ -476,10 +448,7 @@ class ConnectionPool(object):
             if scheme == 'http':
                 cls = HTTPConnection
             elif scheme == 'https':
-                if self.disable_ssl_verification:
-                    cls = InsecureHTTPSConnection
-                else:
-                    cls = HTTPSConnection
+                cls = HTTPSConnection
             else:
                 raise ValueError('%s is not a supported scheme' % scheme)
             conn = cls(host, timeout=self.timeout)
